| Title: | Generate beautiful, customizable word clouds using ggwordcloud from tm Corpus objects. |
|---|---|
| Description: | Generate beautiful, customizable word clouds using ggwordcloud from tm Corpus objects. |
| Authors: | Alfonso Cano |
| Maintainer: | Alfonso Cano <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.0.1 |
| Built: | 2026-06-10 00:44:06 UTC |
| Source: | https://github.com/AlfCano/rk.word.cloud |